@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::GetSentry;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '1.1.3';
+our $VERSION = '1.1.4';
 
 use Data::Dump 'dump';
 use Devel::StackTrace::Extract;
@@ -303,7 +303,7 @@ Handle reporting to Sentry error.
 =cut
 
 sub on_error {
-    my ($self, $method) = (shift, shift);
+    my ($self, $message) = (shift, shift);
 
     die "failed to submit event to sentry service:\n" . dump($self->raven->_construct_message_event($message, @_));
 }
@@ -400,8 +400,8 @@ version 1.0
             return 1 if ($expection->message =~ /Do not log this error/);
         },
 
-        on_error {
-            my ($sentry, $method) = (shift, shift);
+        on_error => sub {
+            my ($self, $message) = (shift, shift);
 
             die "failed to submit event to sentry service:\n" . dump($sentry->raven->_construct_message_event($message, @_));
         }
